package org.verohallinto.apitamoclient.ui;

import org.apache.pivot.beans.BXML;
import org.apache.pivot.beans.BXMLSerializer;
import org.apache.pivot.beans.Bindable;
import org.apache.pivot.collections.Map;
import org.apache.pivot.util.Resources;
import org.apache.pivot.wtk.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.verohallinto.apitamoclient.ApitamopkiClient;
import org.verohallinto.apitamoclient.util.Const;

import java.io.File;
import java.net.URL;

/**
 * Client user interface.
 * </p>
 * https://pivot.apache.org/
 */
public class ApitamopkiClientUI extends Window implements Application, Bindable {

    private static final Logger log = LoggerFactory.getLogger(ApitamopkiClientUI.class);
    private Window window;
    ApitamopkiClientUIAction action;
    ApitamopkiClient apitamo;
    int env;
    File workDir;
    String winUser;
    // WSDL
    URL wsdl;
    // KeyManager
    String ksJks;
    String ksPwd;
    String ksAlias;
    String ksAliasPwd;
    // TrustManager
    String tsJks;
    String tsPwd;
    // Accepted hostname
    String acceptHost;
    // Timeouts
    long connTimeout;
    long readTimeout;
    //
    @BXML
    Menu menuEnv;
    @BXML
    Menu menuCrt;
    @BXML
    Menu menuLog;
    @BXML
    MenuBar.Item crtInfo;
    @BXML
    TabPane tabs;
    @BXML
    protected Label status;
    // Send tab
    FileBrowserSheet materialBrowser;
    FileBrowserSheet attachBrowser;
    FileBrowserSheet resultBrowser;
    @BXML
    PushButton materialPB;
    @BXML
    BoxPane materialBP;
    @BXML
    TextInput material;
    @BXML
    BoxPane sendLanguageBP;
    @BXML
    ButtonGroup sendLanguageBG;
    @BXML
    Checkbox backgroundCB;
    @BXML
    BoxPane emailBP;
    @BXML
    TextInput emails;
    @BXML
    BoxPane attachButtonBP;
    @BXML
    PushButton attachPB;
    @BXML
    PushButton attachClearPB;
    @BXML
    ListView attachLV;
    @BXML
    TextInput sendResult;
    @BXML
    PushButton sendResultPB;
    @BXML
    PushButton sendPB;
    // Retrival tab
    FileBrowserSheet retrBrowser;
    @BXML
    BoxPane retrBP;
    @BXML
    ButtonGroup retrBG;
    @BXML
    RadioButton retrMaterialRB;
    @BXML
    RadioButton retrResultRB;
    @BXML
    BoxPane retrLanguageBP;
    @BXML
    ButtonGroup retrLanguageBG;
    @BXML
    BoxPane retrIdBP;
    @BXML
    TextInput retrId;
    @BXML
    TextInput retrResult;
    @BXML
    PushButton retrResultPB;
    @BXML
    PushButton retrPB;
    // Response tab
    @BXML
    TextArea resLeft;
    @BXML
    TextArea resRight;
    @BXML
    PushButton resClearPB;
    @BXML
    TextInput resFile;
    @BXML
    PushButton resOpenPB;

    /**
     * Constructor
     */
    public ApitamopkiClientUI() {
    }

    @Override
    public void startup(final Display display, final Map<String, String> properties) throws Exception {

        if (log.isDebugEnabled()) {
            log.debug("startup() - begin.");
        }

        final BXMLSerializer serializer = new BXMLSerializer();
        this.window = (Window)serializer.readObject(ApitamopkiClientUI.class, "/ApitamopkiClientUI.bxml");
        serializer.bind(this, ApitamopkiClientUI.class);

        this.window.open(display);

        if (log.isDebugEnabled()) {
            log.debug("startup() - end.");
        }
    }

    @Override
    public boolean shutdown(final boolean optional) {

        if (this.apitamo != null) {
            this.apitamo.destroyClient();
        }

        if (this.window != null) {
            this.window.close();
        }

        return false;
    }

    @Override
    public void suspend() {
    }

    @Override
    public void resume() {
    }

    @Override
    public void initialize(final Map<String, Object> map, final URL url, final Resources resources) {

        if (log.isDebugEnabled()) {
            log.debug("initialize() - begin.");
        }

        this.action = new ApitamopkiClientUIAction(this);
        this.workDir = action.getWorkDir();
        this.env = Const.DEVELOPMENT;
        this.winUser = System.getenv("USERNAME");

        if (this.winUser != null) {
            this.winUser = this.winUser.toLowerCase();
        }

        new MainMenu(this);
        new TabSend(this);
        new TabRetrieve(this);
        new TabResponse(this);

        if (log.isDebugEnabled()) {
            log.debug("initialize() - end. winUser=" + winUser);
        }
    }

    /**
     * Entry point.
     * </p>
     *
     * @param args <code>String</code>[] argumentit.
     */
    public static void main(final String[] args) {

        DesktopApplicationContext.main(ApitamopkiClientUI.class, args);
    }
}
