package org.verohallinto.apitamoclient;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;
import org.verohallinto.apitamoclient.dto.ResponseDTO;
import org.verohallinto.apitamoclient.util.Props;
import org.verohallinto.apitamoclient.util.Utils;

import java.io.File;
import java.net.URL;
import java.util.Collections;
import java.util.Set;

public class ApitamopkiClientTest {

    private static final Logger log = LoggerFactory.getLogger(ApitamopkiClientTest.class);
    private ApitamopkiClient apitamo;
    private String path;

    @BeforeClass
    public void beforeClass() throws Exception {

        Props.init("dev");
        URL wsdl = Utils.getWsdl();
        // KeyManager info
        String ksJks = Props.get("key.store.jks");
        String ksPwd = Props.get("key.store.pwd");
        String ksAlias = Props.get("key.store.alias");
        String ksAliasPwd = Props.get("key.store.alias.pwd");
        String tsJks = Props.get("trust.store.jks");
        String tsPwd = Props.get("trust.store.pwd");
        String acceptHost = Props.get("accept.host");
        // Timeouts
        long connTimeout = Props.getTimeoutConn();
        long readTimeout = Props.getTimeoutRead();
        //
        this.apitamo = new ApitamopkiClient(wsdl,
                                            ksJks,
                                            ksPwd,
                                            ksAlias,
                                            ksAliasPwd,
                                            tsJks,
                                            tsPwd,
                                            acceptHost,
                                            connTimeout,
                                            readTimeout);

        this.path = new File("Result.tmp").getParent();
    }

    @AfterClass
    public void afterClass() throws Exception {

        this.apitamo.destroyClient();
    }

    @Test
    public void testSendOperation() throws Exception {

        String material = "src\\test\\resources\\aineisto\\RVKSSELE_2019_kaikki_suorituslajit_OIK.txt";
        Set<String> attachments = Collections.emptySet();

        ResponseDTO response = this.apitamo.sendOperation("fi",
                                                          "tatu.testaaja@testipenkki.net",
                                                          false,
                                                          material,
                                                          attachments,
                                                          this.path);

        log.info("testSendOperation() end: result=" + response.result);
    }

    @Test
    public void testRetrievalOperation() throws Exception {

        ResponseDTO response = this.apitamo.retrievalOperation("fi",
                                                               "710473fa-ebd8-442c-8b0a-4f2fcc680c93",
                                                               null,
                                                               this.path);

        log.info("testRetrievalOperation() end: result=" + response.result);
    }
}
